package com.example.ellegadodepintia.exploradoresDePintia.model.eventoFactory

import com.example.ellegadodepintia.R
import com.example.ellegadodepintia.exploradoresDePintia.model.GameState
import com.example.ellegadodepintia.exploradoresDePintia.model.Atributo
import com.example.ellegadodepintia.exploradoresDePintia.model.Opcion
import com.example.ellegadodepintia.exploradoresDePintia.model.OpcionCombate
import com.example.ellegadodepintia.exploradoresDePintia.model.efecto.Efecto
import com.example.ellegadodepintia.exploradoresDePintia.model.efecto.EfectoAtaqueEnemigo
import com.example.ellegadodepintia.exploradoresDePintia.model.efecto.EfectoAtaqueProtagonista
import com.example.ellegadodepintia.exploradoresDePintia.model.efecto.EfectoHabilidadesProtagonista
import com.example.ellegadodepintia.exploradoresDePintia.model.efecto.EfectoHuirProtagonista
import com.example.ellegadodepintia.exploradoresDePintia.model.efecto.EfectoInvestigarEnemigo
import com.example.ellegadodepintia.exploradoresDePintia.model.efecto.EfectoRegeneracionEnemigo
import com.example.ellegadodepintia.exploradoresDePintia.model.objeto.Objeto
import com.example.ellegadodepintia.repositorios.RepositorioObjetos

data class CombateInfo(
    val imagenIdle: Int,
    val imagenAtaque: Int,
    val opciones: List<Opcion>,
    val habilidades: List<Efecto>,
    val recompensa: Objeto
)

class CombateFactory : EventoFactory {

    private val combatesMap = mapOf(
        "El Metal Volador es una criatura formada por fragmentos de metal antiguo. Protege los secretos del yacimiento de Pintia." to CombateInfo(
            R.drawable.monster_metal_idle_animation,
            R.drawable.monster_metal_attack_animation,
            listOf(
                OpcionCombate(
                    descripcion = "Atacar",
                    atributoRequerida = Atributo.Ataque,
                    efecto = EfectoAtaqueProtagonista(70)
                ),
                Opcion(
                    descripcion = "Investigar",
                    atributoRequerida = Atributo.Investigacion,
                    efecto = EfectoInvestigarEnemigo(100)
                ),
                Opcion(
                    descripcion = "Habilidades",
                    atributoRequerida = Atributo.Nula,
                    efecto = EfectoHabilidadesProtagonista(GameState.jugador.atributos[Atributo.Vida]!!)
                ),
                OpcionCombate(
                    descripcion = "Huir",
                    atributoRequerida = Atributo.Vida,
                    efecto = EfectoHuirProtagonista(GameState.jugador.atributos[Atributo.Vida]!!),
                ),
            ),
            listOf(
                EfectoAtaqueEnemigo(80),
                EfectoRegeneracionEnemigo("El metal reconfigura sus fragmentos recuperando parte de su vida", (1..2).random())
            ),
            RepositorioObjetos.obtenerObjetoPorNombre("Moneda de plata Vaccea")!!
        ),
    )

    override fun generarDescripcion(): String {
        return combatesMap.keys.random()
    }

    override fun generarEvento(): EventoCombate {
        val descripcion = generarDescripcion()
        val combateInfo = combatesMap[descripcion] ?: throw IllegalArgumentException("No se encontró información de combate")

        return EventoCombate(
            descripcion = descripcion,
            dificultad = 0,
            opciones = combateInfo.opciones.toMutableList(),
            imagenAtaque = combateInfo.imagenAtaque,
            imagen = combateInfo.imagenIdle,
            resistenciaMax = (5..10).random(),
            ataque = (1..2).random(),
            finalizado = false,
            acciones = combateInfo.habilidades.toMutableList(),
            recompensa = combateInfo.recompensa
        )
    }

    override fun generarOpciones(descripcion: String): MutableList<Opcion> {
        val combateInfo = combatesMap[descripcion] ?: return mutableListOf()
        return combateInfo.opciones.take(4).toMutableList()
    }

    override fun generarImagen(descripcion: String): Int {
        return combatesMap[descripcion]!!.imagenIdle
    }

}
