package com.example.ellegadodepintia.exploradoresDePintia.model.eventoFactory

import com.example.ellegadodepintia.R
import com.example.ellegadodepintia.exploradoresDePintia.model.Atributo
import com.example.ellegadodepintia.exploradoresDePintia.model.Opcion
import com.example.ellegadodepintia.exploradoresDePintia.model.efecto.EfectoDetallesCompra
import com.example.ellegadodepintia.exploradoresDePintia.model.efecto.EfectoIgnorar
import com.example.ellegadodepintia.repositorios.RepositorioObjetos


class TiendaFactory : EventoFactory {
    private val tiendasMap = mapOf(
        "Te encuentras al mercader de Pintia, quien te ofrece una pocíon que te restaura 3 puntos de vida por 5 monedas. ¿Te atreves a descubrir su poder?" to Pair(
            R.drawable.asi_exploradores_tienda, listOf(
                Opcion(
                    descripcion = "Ver Objeto",
                    atributoRequerida = Atributo.Nula,
                    EfectoDetallesCompra(
                        5,
                        RepositorioObjetos.obtenerObjetoPorNombre("Elixir Menor de la Necrópolis")!!
                    )
                ), Opcion(
                    descripcion = "Rechazar",
                    atributoRequerida = Atributo.Nula,
                    EfectoIgnorar(100)
                )
            )
        ),
        "Te encuentras al mercader de Pintia, quien te ofrece una pocíon que te restaura 5 puntos de vida por 8 monedas. ¿Te atreves a probarla y sentir su poder renovador?" to Pair(
            R.drawable.asi_exploradores_tienda, listOf(
                Opcion(
                    descripcion = "Ver Objeto",
                    atributoRequerida = Atributo.Nula,
                    EfectoDetallesCompra(
                        8,
                        RepositorioObjetos.obtenerObjetoPorNombre("Elixir Mediano de la Necrópolis")!!
                    )
                ), Opcion(
                    descripcion = "Rechazar",
                    atributoRequerida = Atributo.Nula,
                    EfectoIgnorar(100)
                )
            )
        ),
        "Te encuentras al mercader de Pintia, quien te ofrece una pocíon que te restaura toda la vida por 15 monedas. ¿Te atreves a probarla?" to Pair(
            R.drawable.asi_exploradores_tienda, listOf(
                Opcion(
                    descripcion = "Ver Objeto",
                    atributoRequerida = Atributo.Nula,
                    EfectoDetallesCompra(
                        15,
                        RepositorioObjetos.obtenerObjetoPorNombre("Elixir Supremo de la Necrópolis")!!
                    )
                ), Opcion(
                    descripcion = "Rechazar",
                    atributoRequerida = Atributo.Nula,
                    EfectoIgnorar(100)
                )
            )
        ),
        "Te encuentras al mercader de Pintia, quien te ofrece un escudo equipable que aumenta tu vida máxima en 10 puntos por 50 monedas. ¿Listo para lucirlo en combate?" to Pair(
            R.drawable.asi_exploradores_tienda, listOf(
                Opcion(
                    descripcion = "Ver Objeto",
                    atributoRequerida = Atributo.Nula,
                    EfectoDetallesCompra(
                        50,
                        RepositorioObjetos.obtenerObjetoPorNombre("Escudo Caetrae")!!
                    )
                ), Opcion(
                    descripcion = "Rechazar",
                    atributoRequerida = Atributo.Nula,
                    EfectoIgnorar(100)
                )
            )
        ),
        "Te encuentras al mercader de Pintia, quien te ofrece un casco equipable que aumenta tu vida máxima en 8 puntos por 40 monedas. ¿Te atreves a equiparlo?" to Pair(
            R.drawable.asi_exploradores_tienda, listOf(
                Opcion(
                    descripcion = "Ver Objeto",
                    atributoRequerida = Atributo.Nula,
                    EfectoDetallesCompra(
                        40,
                        RepositorioObjetos.obtenerObjetoPorNombre("Casco Ceremonial")!!
                    )
                ), Opcion(
                    descripcion = "Rechazar",
                    atributoRequerida = Atributo.Nula,
                    EfectoIgnorar(100)
                )
            )
        ),

        )

    override fun generarDescripcion(): String {
        return tiendasMap.keys.random()
    }

    override fun generarOpciones(descripcion: String): MutableList<Opcion> {
        return tiendasMap[descripcion]?.second?.toMutableList()
            ?: mutableListOf()
    }

    override fun generarImagen(descripcion: String): Int {
        return tiendasMap[descripcion]?.first!!
    }

    override fun generarEvento(): EventoTienda {
        val descripcion = generarDescripcion()
        return EventoTienda(
            descripcion = descripcion,
            dificultad = 0,
            opciones = generarOpciones(descripcion),
            imagen = generarImagen(descripcion),
            resistenciaMax = (2..8).random(),
            finalizado = false
        )
    }
}